##############################################################################
#                                                                            #
# Copyright (c) Microsoft Corporation.                                       #
#                                                                            #
# Forefront Protection Server Script Kit (FPSSK)                             #
#                                                                            #
# LICENSED UNDER THE MICROSOFT SOFTWARE LICENSE TERMS PROVIDED WITH THIS     #
# CODE (EULA.RTF). YOUR USE OF THIS CODE IS SUBJECT TO THE TERMS OF THAT     #
# LICENSE. THIS CODE IS PROVIDED *AS IS* WITHOUT WARRANTY OF ANY KIND,       #
# EITHER EXPRESS OR IMPLIED, INCLUDING ANY IMPLIED WARRANTIES OF FITNESS     #
# FOR A PARTICULAR PURPOSE, MERCHANTABILITY, OR NON-INFRINGEMENT.            #
#                                                                            #
##############################################################################

# Global Types
Add-Type @'
public class IncidentData
{
    public int Virus;
    public int Spam;               // Only present in Exchange
    public int Spyware;
    public int KeywordFilter;
    public int SubjectLineFilter;  // Only present in Exchange
    public int FileFilter;
    public int SenderDomainFilter; // Only present in Exchange
    public int Incident;
}
'@

Add-Type @'
public class MalwareData
{
    public int Scanned;
    public int Detected;
    public int Cleaned;        // Only present in Sharepoint
    public int Purged;         // Only present in Exchange
    public int Suspended;      // Only present in Sharepoint
    public int Tagged;         // Only present in Exchange
    public int Deleted;        // Only present in Sharepoint
    public int Skipped;        // Only present in Sharepoint
    public int Quarantined;
    public int PartsScanned;
    public int PartsDetected;
    public int PartsCleaned;
    public int PartsSuspended; // Only present in Sharepoint
    public int PartsDeleted;
    public int PartsSkipped;
    public int PartsQuarantined;
}
'@

Add-Type @'
public class SpamData // Only present in Exchange
{
    public int Received;
    public int Allowed;
    public int Blocked;
    public int Rejected;
    public int Deleted;
    public int Quarantined;
}
'@

# Globals
$ServerInfo = $null       # Server information table

$Health = $null           # Health status
$HealthSum = $null        # Health status summary

$Malware = $null          # Malware report
$MalwareSum = $null       # Malware report summary
$MalwareAll = $null       # Malware cumulative report
$MalwareAllSum = $null    # Malware cumulative report summary

$Spam = $null             # Spam in the last 24 hours report
$SpamSum = $null          # Spam in the last 24 hours report summary
$SpamAll = $null          # Spam all-up report
$SpamAllSum = $null       # Spam all-up report summary

$Incidents = $null        # Incidents in the last 24 hours report
$IncidentsSum = $null     # Incidents in the last 24 hours report summary
$IncidentsAll = $null     # Incidents all-up report
$IncidentsAllSum = $null  # Incidents all-up report summary

$Quarantine = $null       # Quarantine events in the last 24 hours
$QuarantineSum = $null    # Quarantine events in the last 24 hours summary
$QuarantineAll = $null    # Quarantine events all-up report
$QuarantineAllSum = $null # Quarantine events all-up report summary

$SignatureUpdate = $null  # Signature update status

$ReportPs1Loaded = $null  # Detect if this script has been loaded

# Aggregate server information returned from Forefront
function getServerInfo ($ProductInfo, $Licensing, $exchangeMgmtStatus)
{
    # Common set of categories across Exchange/Sharepoint
    $object = New-Object PSObject

    Add-Member `
        -inputObject $object `
        -memberType NoteProperty `
        -name "Computer name" `
        -value $ProductInfo.ComputerName
    Add-Member `
        -inputObject $object `
        -memberType NoteProperty `
        -name "Operating system" `
        -value $ProductInfo.OperatingSystem

    $string = $Licensing.LicensedComponent + " " + $ProductInfo.Version
    Add-Member `
        -inputObject $object `
        -memberType NoteProperty `
        -name "Product" `
        -value $string

    if ($Global:FSEPresent)
    {
        # Categories specific to Exchange
        Add-Member `
            -inputObject $object `
            -memberType NoteProperty `
            -name "Exchange Server role" `
            -value $ProductInfo.Role
        Add-Member `
            -inputObject $object `
            -memberType NoteProperty `
            -name "Exchange Server version" `
            -value $ProductInfo.ExchangeVersion
        Add-Member `
            -inputObject $object `
            -memberType NoteProperty `
            -name "Exchange Server available" `
            -value $exchangeMgmtStatus.ExchangeManagementAvailable
    }
    else
    {
        Add-Member `
            -inputObject $object `
            -memberType NoteProperty `
            -name "SharePoint version" `
            -value $ProductInfo.SharePointVersion
    }

    return $object
}

# Aggregate malware information returned from Forefront
function getMalwareReport ($report, $summary)
{
    $object = New-Object MalwareData

    if ($Global:FSEPresent)
    {
        # Not supported on exchange: Cleaned, Suspended, Deleted, Skipped &
        # PartsSuspended
        $object.Scanned = $report[4].MessagesScanned
        $object.Detected = $report[4].MessagesDetected
        $object.Purged = $report[4].MessagesPurged
        $object.Tagged = $report[4].MessagesTagged
        $object.Quarantined = $report[4].MessagesQuarantined
        $object.PartsScanned = $report[4].MessagePartsScanned
        $object.PartsDetected = $report[4].MessagePartsDetected
        $object.PartsCleaned = $report[4].MessagePartsCleaned
        $object.PartsDeleted = $report[4].MessagePartsDeleted
        $object.PartsSkipped = $report[4].MessagePartsSkipped
        $object.PartsQuarantined = $report[4].MessagePartsQuarantined
    }
    else
    {
        # Not supported on SharePoint: Purged & Tagged
        $object.Scanned = $report[3].FilesScanned
        $object.Detected = $report[3].FilesDetected
        $object.Cleaned = $report[3].FilesCleaned
        $object.Suspended = $report[3].FilesSuspended
        $object.Deleted = $report[3].FilesDeleted
        $object.Skipped = $report[3].FilesSkipped
        $object.Quarantined = $report[3].FilesQuarantined
        $object.PartsScanned = $report[3].FilePartsScanned
        $object.PartsDetected = $report[3].FilePartsDetected
        $object.PartsCleaned = $report[3].FilePartsCleaned
        $object.PartsSuspended = $report[3].FilePartsSuspended
        $object.PartsDeleted = $report[3].FilePartsDeleted
        $object.PartsSkipped = $report[3].FilePartsSkipped
        $object.PartsQuarantined = $report[3].FilePartsQuarantined
    }

    if ($summary -eq $null)
    {
        # If a summary object doesn't exist, use the current dataset
        $summary = $object
    }
    else
    {
        # Add current data to the summary data
        $summary.Scanned += $object.Scanned
        $summary.Detected += $object.Detected
        $summary.Cleaned += $object.Cleaned
        $summary.Purged += $object.Purged
        $summary.Suspended += $object.Suspended
        $summary.Tagged += $object.Tagged
        $summary.Deleted += $object.Deleted
        $summary.Skipped += $object.Skipped
        $summary.Quarantined += $object.Quarantined
        $summary.PartsScanned += $object.PartsScanned
        $summary.PartsDetected += $object.PartsDetected
        $summary.PartsCleaned += $object.PartsCleaned
        $summary.PartsSuspended += $object.PartsSuspended
        $summary.PartsDeleted += $object.PartsDeleted
        $summary.PartsSkipped += $object.PartsSkipped
        $summary.PartsQuarantined += $object.PartsQuarantined
    }

    return $object, $summary
}

# Aggregate incident information returned from Forefront
function getIncidentReport ($Incidents, $summary)
{
    $object = New-Object IncidentData

    # Loop through each incident to count the categories
    foreach ($Incident in $Incidents)
    {
        # Prevent an error in the switch statement below as this loop
        # executes even when there are zero incidents
        if ($Incident -eq $null)
        {
            break
        }

        # Increment a counter for each category type
        switch ($Incident.IncidentCategory)
        {
            "Virus"
            {
                $object.Virus++
                break
            }
            "Spam"
            {
                $object.Spam++
                break
            }
            "Spyware"
            {
                $object.Spyware++
                break
            }
            "KeywordFilter"
            {
                $object.KeywordFilter++
                break
            }
            "SubjectFilter"
            {
                $object.SubjectLineFilter++
                break
            }
            "FileFilter"
            {
                $object.FileFilter++
                break
            }
            "SenderFilter"
            {
                $object.SenderDomainFilter++
                break
            }
            "Incident"
            {
                $object.Incident++
                break
            }
            default
            {
                $warning =
                    "`n`rWarning: Unexpected incident data: " +
                        $Incident.IncidentCategory + "`n`r"
                printWarning $warning
                break
            }
        }
    }

    if ($summary -eq $null)
    {
        # If a summary object doesn't exist, use the current dataset
        $summary = $object
    }
    else
    {
        # Add current data to the summary data
        $summary.Virus += $object.Virus
        $summary.Spam += $object.Spam
        $summary.Spyware += $object.Spyware
        $summary.KeywordFilter += $object.KeywordFilter
        $summary.SubjectLineFilter += $object.SubjectLineFilter
        $summary.FileFilter += $object.FileFilter
        $summary.SenderDomainFilter += $object.SenderDomainFilter
        $summary.Incident += $object.Incident
    }

    return $object, $summary
}

# Aggregate spam information returned from Forefront
function getSpamReport ($Spam, $summary)
{
    $object = New-Object SpamData

    $object.Received =
        $Spam.ConnectionFilterMessagesReceived +
        $Spam.ConnectionIPAllowMessagesReceived +
        $Spam.ConnectionIPBlockMessagesReceived +
        $Spam.ConnectionIPBlockProviderMessagesReceived +
        $Spam.SmtpFilterMessagesReceived +
        $Spam.SmtpSenderFilterMessagesReceived +
        $Spam.SmtpSenderIDFilterMessagesReceived +
        $Spam.SmtpRecipientFilterMessagesReceived +
        $Spam.ContentFilterReceived +
        $Spam.BackscatterFilterMessagesReceived

    $object.Allowed =
        $Spam.ConnectionFilterMessagesAllowed +
        $Spam.ConnectionIPAllowMessagesAllowed +
        $Spam.SmtpFilterAllowActions +
        $Spam.BackscatterFilterMessagesAllowed +
        $Spam.BackscatterMessagesAllowedByDomainExclusionList

    $object.Blocked =
        $Spam.ConnectionFilterMessagesBlocked +
        $Spam.ConnectionIPBlockMessagesBlocked +
        $Spam.ConnectionIPBlockProviderMessagesBlocked +
        $Spam.SmtpFilterBlockActions +
        $Spam.SmtpSenderFilterMessagesBlocked +
        $Spam.SmtpSenderIDFilterMessagesBlocked +
        $Spam.SmtpRecipientFilterMessagesBlocked +
        $Spam.BackscatterFilterMessagesBlocked +
        $Spam.BackscatterMessagesBlockedByDomainRejectList +
        $Spam.BackscatterMessagesBlockedByBATV

    $object.Rejected = $Spam.ContentFilterRejected
    $object.Deleted = $Spam.ContentFilterDeleted
    $object.Quarantined = $Spam.ContentFilterQuarantined

    if ($summary -eq $null)
    {
        # If a summary object doesn't exist, use the current dataset
        $summary = $object
    }
    else
    {
        # Add current data to the summary data
        $summary.Received += $object.Received
        $summary.Allowed += $object.Allowed
        $summary.Blocked += $object.Blocked
        $summary.Rejected += $object.Rejected
        $summary.Deleted += $object.Deleted
        $summary.Quarantined += $object.Quarantined
    }

    return $object, $summary
}

# Walk through the components for each server and note any troubles
function getHealthIssuesSummary
{
    foreach ($healthItem in $Global:Health)
    {
        if ($healthItem.Status -eq "YELLOW" -or $healthItem.Status -eq "RED")
        {
            if ($Global:HealthSum -eq $null)
            {
                $Global:HealthSum = New-Object PSObject
            }

            $name =
                $Global:server.ComputerName + " - " + $healthItem.HealthPoint +
                " (" + $healthItem.Status + ")"

            Add-Member `
                -inputObject $Global:HealthSum `
                -memberType NoteProperty `
                -name  $name `
                -value $healthItem.Message
        }
    }
}

# Worker function which calls all of the reporting functions in Forefront
function getServerStatus
{
    $exchangeMgmtStatus = $null

    # Get the time and date from 24 hours ago
    $Last24Hours = [DateTimeOffset]::Now.Date.AddHours(-24)
    $24HourFilter = " -Filter ""DetectionTime > $Last24Hours"""

    # Build the command strings
    $CmdGet = "Get-" + $Global:extension
    $CmdProductInfo = $CmdGet + "ProductInfo"
    $CmdLicensing = $CmdGet + "Licensing"
    $CmdExchMgmt = $CmdGet + "ExchangeManagementStatus"
    $CmdHealth = $CmdGet + "Health"
    $CmdMalware = $CmdGet + "Report -Type Total"
    $CmdMalwareAll = $CmdMalware + " -Cumulative"
    $CmdIncidentsAll = $CmdGet + "Incident"
    $CmdIncidents = $CmdIncidentsAll + $24HourFilter
    $CmdQuarantineAll = $CmdGet + "Quarantine"
    $CmdQuarantine = $CmdQuarantineAll + $24HourFilter
    $CmdSignatureUpdate = $CmdGet + "SignatureUpdate"
    $CmdSpamReport =
        $CmdGet + "SpamReport -StartTime (Date).AddHours(-24) -EndTime (Date)"
    $CmdSpamReportAll =
        $CmdGet + "SpamReport -StartTime 1/1/1980 -EndTime (Date)"

    # Product information
    $ProductInfo = invokeCommand $CmdProductInfo
    if ($Global:errorString.value -ne $Null)
    {
        return
    }

    # The Forefront Cmd-let doesn't return the Sharepoint version
    if (!$Global:FSEPresent -and ($ProductInfo.SharePointVersion -eq $null))
    {
        $getRegistry =
            "get-itemproperty -path HKLM:SOFTWARE\Microsoft\Windows\" +
            "CurrentVersion\Uninstall\Office14.OSERVER -name DisplayVersion"

        $SharePointVersion = invokeCommand $getRegistry
        $ProductInfo.SharePointVersion = $SharePointVersion.DisplayVersion
    }

    # Licensing information
    $Licensing = invokeCommand $CmdLicensing
    if ($Global:errorString.value -ne $Null)
    {
        return
    }

    # Exchange management indicates the replication status across a domain
    if ($Global:FSEPresent)
    {
        $exchangeMgmtStatus = invokeCommand $CmdExchMgmt
        if ($exchangeMgmtStatus -eq $null)
        {
            return
        }
    }

    # combine the product / licensing information into one table
    $Global:ServerInfo =
        getServerInfo $ProductInfo $Licensing $exchangeMgmtStatus

    # Get the health of the forefront server components
    $Global:Health = invokeCommand $CmdHealth
    if ($Global:errorString.value -ne $Null)
    {
        return
    }
    
    getHealthIssuesSummary

    # Malware report
    $Malware = invokeCommand $CmdMalware
    if ($Global:errorString.value -ne $Null)
    {
        return
    }

    $Global:Malware, $Global:MalwareSum =
        getMalwareReport $Malware $Global:MalwareSum

    # Malware cumulative report
    $MalwareAll = invokeCommand $CmdMalwareAll
    if ($Global:errorString.value -ne $Null)
    {
        return
    }

    $Global:MalwareAll, $Global:MalwareAllSum =
        getMalwareReport $MalwareAll $Global:MalwareAllSum

    # Recent incidents
    $Incidents = invokeCommand $CmdIncidents
    if ($Global:errorString.value -ne $Null)
    {
        return
    }

    $Global:Incidents, $Global:IncidentsSum =
        getIncidentReport $Incidents $Global:IncidentsSum

    # All incidents
    $IncidentsAll = invokeCommand $CmdIncidentsAll
    if ($Global:errorString.value -ne $Null)
    {
        return
    }

    $Global:IncidentsAll, $Global:IncidentsAllSum =
        getIncidentReport $IncidentsAll $Global:IncidentsAllSum

    # Recent quarantine events
    $Quarantine = invokeCommand $CmdQuarantine
    if ($Global:errorString.value -ne $Null)
    {
        return
    }

    $Global:Quarantine, $Global:QuarantineSum =
        getIncidentReport $Quarantine $Global:QuarantineSum

    # All quarantine events
    $QuarantineAll = invokeCommand $CmdQuarantineAll
    if ($Global:errorString.value -ne $Null)
    {
        return
    }

    $Global:QuarantineAll, $Global:QuarantineAllSum =
        getIncidentReport $QuarantineAll $Global:QuarantineAllSum

    # Signature status
    $Global:SignatureUpdate = invokeCommand $CmdSignatureUpdate
    if ($Global:errorString.value -ne $Null)
    {
        return
    }

    if ($Global:FSEPresent)
    {
        # Recent SPAM
        $Spam = invokeCommand $CmdSpamReport
        if ($Global:errorString.value -ne $Null)
        {
            return
        }

        $Global:Spam, $Global:SpamSum = getSpamReport $Spam $Global:SpamSum

        # All SPAM
        $SpamAll = invokeCommand $CmdSpamReportAll
        if ($Global:errorString.value -ne $Null)
        {
            return
        }

        $Global:SpamAll, $Global:SpamAllSum =
            getSpamReport $SpamAll $Global:SpamAllSum
    }
}

# Print report
function global:cmdReport
{
    # Get all the server information to build the report
    getServerStatus
    if ($Global:errorString.value -ne $Null)
    {
        $errorMessage =
            "Error: Report failed against " + $Global:server.ComputerName
        printError $errorMessage
        return
    }

    # Print results
    printSeparator
    printSeparator

    $Global:ServerInfo | Format-List | Out-Host

    printSeparator
    
    write-host "`n`rForefront Server - Health status`n`r"
    $Global:Health |
        Format-Table `
            -Autosize `
            -Property Status, HealthPoint, LastUpdate |
        Out-Host

    printSeparator
    
    write-host "`n`rForefront Server - Malware detections`n`r"
    write-host "`n`rCurrent malware report:`n`r"
    if ($Global:FSEPresent)
    {
        $Global:Malware |
            Format-List `
                -property Scanned, Detected, Purged, Tagged, Quarantined, `
                    PartsScanned, PartsDetected, PartsCleaned, PartsDeleted, `
                    PartsSkipped, PartsQuarantined |
            Out-Host
    }
    else
    {
        $Global:Malware |
            Format-List `
                -property Scanned, Detected, Cleaned, Suspended, Deleted, `
                    Skipped, Quarantined, PartsScanned, PartsDetected, `
                    PartsCleaned, PartsSuspended, PartsDeleted, `
                    PartsSkipped, PartsQuarantined |
            Out-Host
    }
    
    write-host "`n`rCumulative malware report:`n`r"
    if ($Global:FSEPresent)
    {
        $Global:MalwareAll |
            Format-List `
                -property Scanned, Detected, Purged, Tagged, Quarantined, `
                    PartsScanned, PartsDetected, PartsCleaned, PartsDeleted, `
                    PartsSkipped, PartsQuarantined |
            Out-Host
    }
    else
    {
        $Global:MalwareAll |
            Format-List `
                -property Scanned, Detected, Cleaned, Suspended, Deleted, `
                    Skipped, Quarantined, PartsScanned, PartsDetected, `
                    PartsCleaned, PartsSuspended, PartsDeleted, `
                    PartsSkipped, PartsQuarantined |
            Out-Host
    }

    printSeparator
    
    if ($Global:FSEPresent)
    {
        write-host "`n`rForefront Server - Spam messages`n`r"
        write-host "`n`rSpam in the last 24 hours:`n`r"
        $Global:Spam | Format-List | Out-Host
        write-host "`n`rAll spam:`n`r"
        $Global:SpamAll | Format-List | Out-Host
    
        printSeparator
    }

    write-host "`n`rForefront Server - Incidents`n`r"
    write-host "`n`rIncidents in the last 24 hours:`n`r"
    if ($Global:FSEPresent)
    {
        $Global:Incidents | Format-List | Out-Host
    }
    else
    {
        $Global:Incidents |
            Format-List `
                -property Virus, Spyware, KeywordFilter, FileFilter, Incident |
            Out-Host
    }

    write-host "`n`rAll incidents:`n`r"
    if ($Global:FSEPresent)
    {
        $Global:IncidentsAll | Format-List | Out-Host
    }
    else
    {
        $Global:IncidentsAll |
            Format-List `
                -property Virus, Spyware, KeywordFilter, FileFilter, Incident |
            Out-Host
    }

    printSeparator

    write-host "`n`rForefront Server - Quarantine`n`r"
    write-host "`n`rQuarantine events in the last 24 hours:`n`r"
    if ($Global:FSEPresent)
    {
        $Global:Quarantine | Format-List | Out-Host
    }
    else
    {
        $Global:Quarantine |
            Format-List `
                -property Virus, Spyware, KeywordFilter, FileFilter, Incident |
            Out-Host
    }

    write-host "`n`rAll quarantine events:`n`r"
    if ($Global:FSEPresent)
    {
        $Global:QuarantineAll | Format-List | Out-Host
    }
    else
    {
        $Global:QuarantineAll |
            Format-List `
                -property Virus, Spyware, KeywordFilter, FileFilter, Incident |
            Out-Host
    }

    printSeparator

    write-host "`n`rForefront Server - Signature updates`n`r"
    $Global:SignatureUpdate |
        Format-Table `
            -Autosize `
            -Property Engine, EngineInUse, EnableSchedule, EngineVersion, `
				SignatureVersion, LastUpdate, LastCheck |
        Out-Host
}

# Prints a summary report (if more than one computer was specified)
function global:cmdReportSummary
{
    printSeparator
    printSeparator
    write-host "`n`rForefront Server Summary Report`n`r"

    printSeparator

    if ($Global:HealthSum -ne $null)
    {
        write-host "`n`rForefront Server - Health issues detected`n`r"
        $Global:HealthSum | Format-List | Out-Host

        printSeparator
    }

    write-host "`n`rForefront Server - Malware detections`n`r"
    write-host "`n`rCurrent malware report:`n`r"
    $Global:MalwareSum | Format-List | Out-Host
    write-host "`n`rCumulative malware report:`n`r"
    $Global:MalwareAllSum | Format-List | Out-Host

    printSeparator

    write-host "`n`rForefront Server - Spam messages`n`r"
    write-host "`n`rSpam in the last 24 hours:`n`r"
    $Global:SpamSum | Format-List | Out-Host
    write-host "`n`rAll spam:`n`r"
    $Global:SpamAllSum | Format-List | Out-Host

    printSeparator

    write-host "`n`rForefront Server - Incidents`n`r"
    write-host "`n`rIncidents in the last 24 hours:`n`r"
    $Global:IncidentsSum | Format-List | Out-Host
    write-host "`n`rAll incidents:`n`r"
    $Global:IncidentsAllSum | Format-List | Out-Host

    printSeparator

    write-host "`n`rForefront Server - Quarantine`n`r"
    write-host "`n`rQuarantine events in the last 24 hours:`n`r"
    $Global:QuarantineSum | Format-List | Out-Host
    write-host "`n`rAll quarantine events:`n`r"
    $Global:QuarantineAllSum | Format-List | Out-Host
}

# Make sure all the summary stats are zero'd when the script is loaded
$Global:MalwareSum = $Global:MalwareAllSum = $Global:IncidentsSum =
    $Global:IncidentsAllSum = $Global:SpamSum = $Global:SpamAllSum =
    $Global:QuarantineSum = $Global:QuarantineAllSum = $Global:HealthSum = $null

# This will flag that this script and it's functions have been loaded
$Global:ReportPs1Loaded = $true

# SIG # Begin signature block
# MIIbKAYJKoZIhvcNAQcCoIIbGTCCGxUCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUdjcMtq5+a0mb/VhFaCPk1OEY
# epegghXnMIIEhTCCA22gAwIBAgIKYQX3HgAAAAAAMjANBgkqhkiG9w0BAQUFADB5
# MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
# bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSMwIQYDVQQDExpN
# aWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQTAeFw0wOTA3MTMyMzAwMThaFw0xMDEw
# MTMyMzEwMThaMIGDMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQ
# MA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9u
# MQ0wCwYDVQQLEwRNT1BSMR4wHAYDVQQDExVNaWNyb3NvZnQgQ29ycG9yYXRpb24w
# ggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC1jKmclIRhGswuIsSgk2QJ
# 3oWhsJBd/MlsaLXx7/yOa/T4oG7XUd5goydj1PbftkzSRQunPdhv/u2nGGPTH8aB
# 1L8HN5dAK3/nX1o12ZNPq/MqkvCmjYHsBSTc27hhY1NhAjU41rj17ntUpslYNen0
# Fe/aB2wFLU2ktrqbO7gxMH5FvKmhJTkMQ6RHO5ecIERyN89QoE1N9MNl3ETRCDs4
# 3T7FF2xGx61zJMCPicHq6rrNaKkS1lgMUxYM/jkD1oHyPlxX83rbZuEHGNkZAxT2
# 5kWZKlFMkNda76+3OwwpTW0grge3ki7oacqfMELnwzKKCyJKMuicDMZRAyYBbZJz
# AgMBAAGjggECMIH/MBMGA1UdJQQMMAoGCCsGAQUFBwMDMB0GA1UdDgQWBBSHgbff
# 7vp3+lkFYzcECtfp2qDg4DAOBgNVHQ8BAf8EBAMCB4AwHwYDVR0jBBgwFoAUV0V0
# HF2w9shDBeCMVC2PMqf+SJYwSQYDVR0fBEIwQDA+oDygOoY4aHR0cDovL2NybC5t
# aWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMvQ29kZVNpZ1BDQS5jcmwwTQYI
# KwYBBQUHAQEEQTA/MD0GCCsGAQUFBzAChjFodHRwOi8vd3d3Lm1pY3Jvc29mdC5j
# b20vcGtpL2NlcnRzL0NvZGVTaWdQQ0EuY3J0MA0GCSqGSIb3DQEBBQUAA4IBAQA2
# IYT1j4MhTYeoP4vnxaQPTDBuWXSbC5d0Fqmx83Ckr8IMMyTzoEr6weQhxrbZ6lxb
# kWH3Im3/MfwXTtfNQOOd0uW00vqNbAfad5rKK+4NWUfPBMIQZ/rq6UM7t+bRnNmO
# I2BuEpvD2X5cVzLdlA3ffcVIkk1IdreiwFOVPvw6o5N88oUEx8aFOJc2+BKTIgCZ
# TnmvlutaIIOs0FxaMLAA4ms5jySJ2j0MpEZ5YjZTatfJzZII+4flVPV8WcXEd32w
# wSyYx5dsQ6f4IPiDVGSeYPjiSqVn1Em/VIh9UkTzUcAm0cV88InWEQkowkVFgB2Q
# Ir2OogU+PLNPvdc54IiTMIIEyjCCA7KgAwIBAgIKYQPc9gAAAAAADDANBgkqhkiG
# 9w0BAQUFADB3MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
# A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSEw
# HwYDVQQDExhNaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EwHhcNMDgwNzI1MTkxMjUw
# WhcNMTEwNzI1MTkyMjUwWjCBszELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
# bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
# b3JhdGlvbjENMAsGA1UECxMETU9QUjEnMCUGA1UECxMebkNpcGhlciBEU0UgRVNO
# OjE1OUMtQTNGNy0yNTcwMSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFtcCBT
# ZXJ2aWNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwO2BFKFed8Bb
# 9HaJYvqtfGgUtPe9NdgTeVoXytlsUUViJnovH9jqwW4BF/nDph9n21GwLN6KF+3/
# IK006pj7pdYq0vFEJwdaLTqT/1ZTsMj18wPyScwW0PUATFj4m/UHJbFmF8C9yNJS
# hY3CKziywza++Yfa9I5dQ9cGv5kFn6TO/quNYWPnOcXzGPbY/DE2aXJaohpMPuqH
# JUKd0T7xl9IYMpNwVVOBHuM7Dei+gnht5vrNmKRv2+5m9JXIzTXJnrs2DYOWlCan
# kOCpNDvVwJ4+8NRHjYYMgqRYMDocduOtlWa0t/0JigVgD6MP4pOWWCKcnSvbopQY
# kJUCvQZAlQIDAQABo4IBGTCCARUwHQYDVR0OBBYEFNLtDR4kuzep2CBqTR3SFtUu
# vp7rMB8GA1UdIwQYMBaAFCM0+NlSRnAK7UD7dvuzK7DDNbMPMFQGA1UdHwRNMEsw
# SaBHoEWGQ2h0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3JsL3Byb2R1Y3Rz
# L01pY3Jvc29mdFRpbWVTdGFtcFBDQS5jcmwwWAYIKwYBBQUHAQEETDBKMEgGCCsG
# AQUFBzAChjxodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpL2NlcnRzL01pY3Jv
# c29mdFRpbWVTdGFtcFBDQS5jcnQwEwYDVR0lBAwwCgYIKwYBBQUHAwgwDgYDVR0P
# AQH/BAQDAgbAMA0GCSqGSIb3DQEBBQUAA4IBAQCcClXIzEQTNAzYYyd2fT76ODKD
# U53yCPky9cVucKHJsWNrGZ0JZ9md64pq22Bm6elSJvM7xmrTwlK+qLnraqp4jMkW
# fZCVoMwhs56Bvc3Biym9YiXvCVfnhk4q7IDKu/whFsQ/TlIZ5g6x2MHCeZBktFBz
# EDVeXRHBuLqqz1L2gJEA5u9RQ0bp0OiU9iwkDYrGsjGKo342bKQFTGcHKru7EKWl
# MBpy0AYgOySTWxXZOZPTcy0axNRsHqEI7PYxuGtL7O5cMwIUMox8ESAvIAN/+Qyd
# uNOeX9YI/IGgmbi7VW7NQks6TYwUK8rIEtNibuoNCp0Jo2bZeU+OGqL/zJgEMIIG
# BzCCA++gAwIBAgIKYRZoNAAAAAAAHDANBgkqhkiG9w0BAQUFADBfMRMwEQYKCZIm
# iZPyLGQBGRYDY29tMRkwFwYKCZImiZPyLGQBGRYJbWljcm9zb2Z0MS0wKwYDVQQD
# EyRNaWNyb3NvZnQgUm9vdCBDZXJ0aWZpY2F0ZSBBdXRob3JpdHkwHhcNMDcwNDAz
# MTI1MzA5WhcNMjEwNDAzMTMwMzA5WjB3MQswCQYDVQQGEwJVUzETMBEGA1UECBMK
# V2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
# IENvcnBvcmF0aW9uMSEwHwYDVQQDExhNaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0Ew
# ggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCfoWyx39tIkip8ay4Z4b3i
# 48WZUSNQrc7dGE4kD+7Rp9FMrXQwIBHrB9VUlRVJlBtCkq6YXDAm2gBr6Hu97IkH
# D/cOBJjwicwfyzMkh53y9GccLPx754gd6udOo6HBI1PKjfpFzwnQXq/QsEIEovmm
# bJNn1yjcRlOwhtDlKEYuJ6yGT1VSDOQDLPtqkJAwbofzWTCd+n7Wl7PoIZd++NIT
# 8wi3U21StEWQn0gASkdmEScpZqiX5NMGgUqi+YSnEUcUCYKfhO1VeP4Bmh1QCIUA
# EDBG7bfeI0a7xC1Un68eeEExd8yb3zuDk6FhArUdDbH895uyAc4iS1T/+QXDwiAL
# AgMBAAGjggGrMIIBpzAPBgNVHRMBAf8EBTADAQH/MB0GA1UdDgQWBBQjNPjZUkZw
# Cu1A+3b7syuwwzWzDzALBgNVHQ8EBAMCAYYwEAYJKwYBBAGCNxUBBAMCAQAwgZgG
# A1UdIwSBkDCBjYAUDqyCYEBWJ5flJRP8KuEKU5VZ5KShY6RhMF8xEzARBgoJkiaJ
# k/IsZAEZFgNjb20xGTAXBgoJkiaJk/IsZAEZFgltaWNyb3NvZnQxLTArBgNVBAMT
# JE1pY3Jvc29mdCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0eYIQea0WoUqgpa1M
# c1j0BxMuZTBQBgNVHR8ESTBHMEWgQ6BBhj9odHRwOi8vY3JsLm1pY3Jvc29mdC5j
# b20vcGtpL2NybC9wcm9kdWN0cy9taWNyb3NvZnRyb290Y2VydC5jcmwwVAYIKwYB
# BQUHAQEESDBGMEQGCCsGAQUFBzAChjhodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20v
# cGtpL2NlcnRzL01pY3Jvc29mdFJvb3RDZXJ0LmNydDATBgNVHSUEDDAKBggrBgEF
# BQcDCDANBgkqhkiG9w0BAQUFAAOCAgEAEJeKw1wDRDbd6bStd9vOeVFNAbEudHFb
# bQwTq86+e4+4LtQSooxtYrhXAstOIBNQmd16QOJXu69YmhzhHQGGrLt48ovQ7DsB
# 7uK+jwoFyI1I4vBTFd1Pq5Lk541q1YDB5pTyBi+FA+mRKiQicPv2/OR4mS4N9wfi
# cLwYTp2OawpylbihOZxnLcVRDupiXD8WmIsgP+IHGjL5zDFKdjE9K3ILyOpwPf+F
# ChPfwgphjvDXuBfrTot/xTUrXqO/67x9C0J71FNyIe4wyrt4ZVxbARcKFA7S2hSY
# 9Ty5ZlizLS/n+YWGzFFW6J1wlGysOUzU9nm/qhh6YinvopspNAZ3GmLJPR5tH4Lw
# C8csu89Ds+X57H2146SodDW4TsVxIxImdgs8UoxxWkZDFLyzs7BNZ8ifQv+AeSGA
# nhUwZuhCEl4ayJ4iIdBD6Svpu/RIzCzU2DKATCYqSCRfWupW76bemZ3KOm+9gSd0
# BhHudiG/m4LBJ1S2sWo9iaF2YbRuoROmv6pH8BJv/YoybLL+31HIjCPJZr2dHYcS
# ZAI9La9Zj7jkIeW1sMpjtHhUBdRBLlCslLCleKuzoJZ1GtmShxN1Ii8yqAhuoFuM
# Jb+g74TKIdbrHk/Jmu5J4PcBZW+JC33Iacjmbuqnl84xKf8OxVtc2E0bodj6L54/
# LlUWa8kTo/0wggaBMIIEaaADAgECAgphFQgnAAAAAAAMMA0GCSqGSIb3DQEBBQUA
# MF8xEzARBgoJkiaJk/IsZAEZFgNjb20xGTAXBgoJkiaJk/IsZAEZFgltaWNyb3Nv
# ZnQxLTArBgNVBAMTJE1pY3Jvc29mdCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0
# eTAeFw0wNjAxMjUyMzIyMzJaFw0xNzAxMjUyMzMyMzJaMHkxCzAJBgNVBAYTAlVT
# MRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
# ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xIzAhBgNVBAMTGk1pY3Jvc29mdCBDb2Rl
# IFNpZ25pbmcgUENBMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAn43f
# hTeMsQZWZjZO1ArrNiORHq+rjVjpxM/BnzoKJMTExF6w7hUUxfo+mTNrGWly9HwF
# X+WZJUTXNRmKkNwojpAM79WQYa3e3BhwLYPJb6+FLPjdubkw/XF4HIP9yKm5gmcN
# erjBCcK8FpdXPxyY02nXMJCQkI0wH9gm1J57iNniCe2XSUXrBFKBdXu4tSK4Lla7
# 18+pTjwKg6KoOsWttgEOas8itCMfbNUn57d+wbTVMq15JRxChuKdhfRX2htZLy0m
# kinFs9eFo55gWpTme5x7XoI0S23/1O4n0KLc0ZAMzn0OFXyIrDTHwGyYhErJRHlo
# KN8igw24iixIYeL+EQIDAQABo4ICIzCCAh8wEAYJKwYBBAGCNxUBBAMCAQAwHQYD
# VR0OBBYEFFdFdBxdsPbIQwXgjFQtjzKn/kiWMAsGA1UdDwQEAwIBxjAPBgNVHRMB
# Af8EBTADAQH/MIGYBgNVHSMEgZAwgY2AFA6sgmBAVieX5SUT/CrhClOVWeSkoWOk
# YTBfMRMwEQYKCZImiZPyLGQBGRYDY29tMRkwFwYKCZImiZPyLGQBGRYJbWljcm9z
# b2Z0MS0wKwYDVQQDEyRNaWNyb3NvZnQgUm9vdCBDZXJ0aWZpY2F0ZSBBdXRob3Jp
# dHmCEHmtFqFKoKWtTHNY9AcTLmUwUAYDVR0fBEkwRzBFoEOgQYY/aHR0cDovL2Ny
# bC5taWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMvbWljcm9zb2Z0cm9vdGNl
# cnQuY3JsMFQGCCsGAQUFBwEBBEgwRjBEBggrBgEFBQcwAoY4aHR0cDovL3d3dy5t
# aWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNyb3NvZnRSb290Q2VydC5jcnQwdgYD
# VR0gBG8wbTBrBgkrBgEEAYI3FS8wXjBcBggrBgEFBQcCAjBQHk4AQwBvAHAAeQBy
# AGkAZwBoAHQAIACpACAAMgAwADAANgAgAE0AaQBjAHIAbwBzAG8AZgB0ACAAQwBv
# AHIAcABvAHIAYQB0AGkAbwBuAC4wEwYDVR0lBAwwCgYIKwYBBQUHAwMwDQYJKoZI
# hvcNAQEFBQADggIBADC8sCCkYqCn7zkmYT3crMaZ0IbELvWDMmVeIj6b1ob46Laf
# yovWO3ULoZE+TN1kdIxJ8oiMGGds/hVmRrg6RkKXyJE31CSx56zT6kEUg3fTyU8F
# X6MUUr+WpC8+VlsQdc5Tw84FVGm0ZckkpQ/hJbgauU3lArlQHk+zmAwdlQLuIlmt
# IssFdAsERXsEWeDYD7PrTPhg3cJ4ntG6n2v38+5+RBFA0r26m0sWCG6kvlXkpjgS
# o0j0HFV6iiDRff6R25SPL8J7a6ZkhU+j5Sw0KV0Lv/XHOC/EIMRWMfZpzoX4CpHs
# 0NauujgFDOtuT0ycAymqovwYoCkMDVxcViNX2hyWDcgmNsFEy+Xh5m+J54/pmLVz
# 03jj7aMBPHTlXrxs9iGJZwXsl521sf2vpulypcM04S+f+fRqOeItBIJb/NCcrnyd
# EfnmtVMZdLo5SjnrfUKzSjs3PcJKeyeY5+JOmxtKVDhqIze+ardI7upCDUkkkY63
# BC6Xb+TnRbuPTf1g2ddZwtiA1mA0e7ehkyD+gbiqpVwJ6YoNvihNftfoD+1leNEx
# X7lm299C5wvMAgeN3/8gBqNFZbSzMo0ukeJNtKnJ+rxrBA6yn+qf3qTJCpb0jffY
# mKjwhQIIWaQgpiwLGvJSBu1p5WQYG+Cjq97KfBRhQ7hl9TajVRMrZyxNGzBMMYIE
# qzCCBKcCAQEwgYcweTELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24x
# EDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
# bjEjMCEGA1UEAxMaTWljcm9zb2Z0IENvZGUgU2lnbmluZyBQQ0ECCmEF9x4AAAAA
# ADIwCQYFKw4DAhoFAKCB2DAZBgkqhkiG9w0BCQMxDAYKKwYBBAGCNwIBBDAcBgor
# BgEEAYI3AgELMQ4wDAYKKwYBBAGCNwIBFTAjBgkqhkiG9w0BCQQxFgQUnnNOe28L
# eqApg6+hYaML3AtqCuEweAYKKwYBBAGCNwIBDDFqMGigToBMAEYAbwByAGUAZgBy
# AG8AbgB0ACAAUAByAG8AdABlAGMAdABpAG8AbgAgAFMAZQByAHYAZQByACAAUwBj
# AHIAaQBwAHQAIABLAGkAdKEWgBRodHRwOi8vbWljcm9zb2Z0LmNvbTANBgkqhkiG
# 9w0BAQEFAASCAQAEMoCfXml2DHxuXi7LWb7Nw5++TX6cScdkd6z9VKZmHaBKYtAl
# hj2aX+6wS/JMlo3lr4Ydz/Fp4SKJ1c7+PPGQq9coylVXePzTfoEqrc/X7XfhDd/9
# fiiACaS8aqu7e/TFbEotTJa9ZN+1YXMFIlQ9BYZGn2R+JaTD5MqvNmByUeIc4gVh
# G0wA3YHpHWHK8gF7wbn3AaSWARWSwUZ3jVBPgIY7CTwum3U+cfyBhA6wUbqOTkdr
# 92sKJjly/gj8PAvXYV3mLz0TfyNF6eaDH3AekiPsQ+2enIKjhCtuSDeXnVIcdCZI
# 1cJ0BJlsqtLoUQUp8kfSexw1zz20BYUZNgrVoYICHTCCAhkGCSqGSIb3DQEJBjGC
# AgowggIGAgEBMIGFMHcxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9u
# MRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
# b24xITAfBgNVBAMTGE1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQQIKYQPc9gAAAAAA
# DDAHBgUrDgMCGqBdMBgGCSqGSIb3DQEJAzELBgkqhkiG9w0BBwEwHAYJKoZIhvcN
# AQkFMQ8XDTEwMDcyNzIyNTUxNlowIwYJKoZIhvcNAQkEMRYEFPmxDW/KsBHYCEM4
# rjOiQNUTAjWHMA0GCSqGSIb3DQEBBQUABIIBAIgrGiSacmQ/lm6uLYxeplbsigcN
# AGCY8wg5Xw8rrUHEVWi1KzbO+YluWs+EGLxe34zNW8uSXDMN3xWoVHj0K0WkYHUr
# LXWK62+SAe7dlpwbNvDdYCwJcBGxJFg81e9k9hLNm4Tp5uUNEIDFe6rxwokNor/D
# dh1M4/vOFvygqX2F6V0s/NS5qS64haGD7hv0QK3oz5NEaJkACgwwxYUwxOmUDjLn
# +Xmdh6U1Qi1mMTmJuoV8F5ZUnrYlqUWXtm1rb4Q4RyIa3yFElrybhjGGBtLuDahb
# tcgkrR0tupQejMuINht02RRclW87JbhSCARlbgKP9IUR/lsco7+aPdmSGAY=
# SIG # End signature block
